@@ -262,10 +262,13 @@ class PostgreSQLAdaptor(object):
     def get_foreignkey_field_create_query_base(self):
         return '%s INTEGER'
 
-    def get_foreignkey_field_create_query_extension(self, reference):
+    def get_foreignkey_field_create_query_extension(self, reference, cascade=''):
+        if cascade != '':
+             cascade = ' ON DELETE %' % cascade.upper()
+
         if type(DbObject) == type(reference):
             reference = reference.tablename
-        return 'FOREIGN KEY(%%s) REFERENCES "%s"(id)' % (reference)
+        return 'FOREIGN KEY(%%s) REFERENCES "%s"(id)%s' % (reference, cascade)
 
     def create_migration_table(self):
         query = """CREATE TABLE IF NOT EXISTS nopea_migrations
